
# R van Woesik and C Cacciapaglia
# 
# Keeping up with sea-level rise: carbonate production rates in Palau and Yap, western Pacific Ocean
# 
# Code to randomly select stratified study sites on on Palauan reefs 


#Libraries that you will need
library(maptools)
library(sp)
library(rgdal)
library(plotGoogleMaps)
library(spatstat)
library(GISTools)
library(PBSmapping)
library(raster)
library(rgeos)
####################################
#get shapefiles

#forereef
palaufore <- readOGR("Shapefiles","fore_reefs")
prj <- CRS("+proj=utm +datum=WGS84 +zone=53 +north")
plot(palaufore, border="orange", axes=TRUE, las=1) # las, labels text horizontal or perpendicular to #axis
#inner reef
palinner <- readOGR("Shapefiles","land_no babeldaob_1")
plot(palinner, border="green", axes=TRUE, las=1,add=T)
#patch reef
palpatch <- readOGR("Shapefiles","patch reefs")
plot(palpatch, border="lightblue",add=T)

#convert to lat lon
prjlonlat<-CRS('+proj=longlat +datum=WGS84')
palaufore<-spTransform(palaufore,prjlonlat)
palinner<-spTransform(palinner,prjlonlat)
palpatch<-spTransform(palpatch,prjlonlat)

#crop extent and re-plot
e<-raster::`extent`(c(134.162336,134.652938,7.18335,7.790720))
palaufore<-crop(palaufore,e)
palinner<-crop(palinner,e)
palpatch<-crop(palpatch,e)

plot(palaufore, border="orange", axes=TRUE, las=1) # las, labels text horizontal or perpendicular to #axis
plot(palinner, border="green", axes=TRUE, las=1,add=T)
plot(palpatch, border="lightblue",add=T)

#sample, and add points
p.randomouter<- spsample(palaufore, n=8, "random")
p.randominner<- spsample(palinner, n=6, "random")
p.randompatch<- spsample(palpatch, n=10, "random")
points(p.randominner, pch=3, col='forestgreen', cex=2,lwd=2)
points(p.randomouter, pch=3, col='red', cex=2,lwd=2)
points(p.randompatch, pch=3, col='blue', cex=2,lwd=2)

#Make a table:
p.randomouter@coords
p.randominner@coords
p.randompatch@coords


#####################################